﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
//using System.Threading.Tasks;
using System.Windows.Forms;
using Phidget22;
using Phidget22.Events;
using Phidget22.ExampleUtils;

namespace PowerGuard_Example
{
    public partial class Form1 : Form
    {
        CommandLineOpen open;
        formCleaner cleaner;
        PowerGuard powerGuard = null;
        private ErrorEventBox errorBox;

        public Form1()
        {
            open = new CommandLineOpen(this);
            cleaner = new formCleaner(this);
            InitializeComponent();
        }

        public Form1(String[] commandLine)
        {
            open = new CommandLineOpen(this);
            cleaner = new formCleaner(this);
            open.commandLine = commandLine;
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            fanCombo.DataSource = typeof(FanMode).ToList();
            fanCombo.SelectedIndex = -1;

            
            errorBox = new ErrorEventBox(this);
            powerGuard = new PowerGuard();

            powerGuard.Attach += new Phidget22.Events.AttachEventHandler(powerGuard_attach);
            powerGuard.Detach += new Phidget22.Events.DetachEventHandler(powerGuard_detach);
            powerGuard.Error += new Phidget22.Events.ErrorEventHandler(powerGuard_error);

            commandLineData phidgetParameters = open.parseCmdLine(); //get command line parameters

            try
            { //set all the values grabbed from command line.  these values have defaults that are set in ExampleUtils.cs, you can check there to see them.
                powerGuard.Channel = phidgetParameters.Channel; //selects the channel on the device to open
                powerGuard.DeviceSerialNumber = phidgetParameters.SerialNumber; //selects the device or hub to open
                powerGuard.HubPort = phidgetParameters.HubPort; //selects the port on the hub to open
                powerGuard.IsHubPortDevice = phidgetParameters.isHubPortDevice; //is the device a port on a VINT hub?

                if (phidgetParameters.isRemote) //are we trying to open a remote device?
                {
                    powerGuard.IsRemote = true;
                    Net.EnableServerDiscovery(ServerType.Device); //turn on network scan
                    if (phidgetParameters.Password != null && phidgetParameters.ServerName != null)
                        Net.SetServerPassword(phidgetParameters.ServerName, phidgetParameters.Password); //set the password if there is one
                }
                else
                    powerGuard.IsLocal = true;

                powerGuard.Open(); //open the device specified by the above parameters
            }
            catch (PhidgetException ex) { errorBox.addMessage("Error opening device: " + ex.Message); }

        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            powerGuard.Attach -= new Phidget22.Events.AttachEventHandler(powerGuard_attach);
            powerGuard.Detach -= new Phidget22.Events.DetachEventHandler(powerGuard_detach);
            powerGuard.Error -= new Phidget22.Events.ErrorEventHandler(powerGuard_error);
            Application.DoEvents();
            powerGuard.Close();
        }

        void powerGuard_attach(object sender, Phidget22.Events.AttachEventArgs e)
        {
            phidgetInfoBox1.FillPhidgetInfo((Phidget)sender);

            settingsBox.Visible = true;

            try
            {
                fanCombo.SelectedIndex = 0;
                powerGuard.OverVoltage = overVoltageTrk.Value;
                powerGuard.PowerEnabled = enablechk.Checked;
            }
            catch (PhidgetException ex)
            { errorBox.addMessage("Error initializing device: " + ex.Message); }

        }

        void powerGuard_detach(object sender, Phidget22.Events.DetachEventArgs e)
        {
            phidgetInfoBox1.Clear();
            cleaner.clean();

            settingsBox.Visible = false;
        }

        void powerGuard_error(object sender, Phidget22.Events.ErrorEventArgs e)
        {
            errTxt.Text = e.Description;
            errorBox.addMessage(e.Description);
        }


        private void overVoltage_Scroll(object sender, EventArgs e)
        {
            try
            {
                powerGuard.OverVoltage = overVoltageTrk.Value;
                overVoltageTxt.Text = powerGuard.OverVoltage.ToString();
            }
            catch (PhidgetException ex)
            { MessageBox.Show(ex.ToString()); }
        }

        private void enablechk_CheckedChanged(object sender, EventArgs e)
        {
            try
            {
                powerGuard.PowerEnabled = enablechk.Checked;
            }
            catch (PhidgetException ex)
            { MessageBox.Show(ex.ToString()); }
        }

        private void fanCombo_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (((ComboBox)sender).SelectedIndex == -1 || powerGuard == null)
                return;
            try
            {
                powerGuard.FanMode = (FanMode)Enum.Parse(typeof(FanMode), fanCombo.SelectedValue.ToString());
            }
            catch (PhidgetException ex)
            { errorBox.addMessage("Error setting fan mode: " + ex.Message); }
        }


    }
}
